CCL: /home/chisarie/Documents/lsst_ccl/CCL/tests/ccl_example_photoz.c File Reference

CCL

Data Structures | Functions
ccl_example_photoz.c File Reference
`#include "ccl_lsst_specs.h"`
`#include "math.h"`
`#include "stdio.h"`
`#include "stdlib.h"`

## Data Structures
struct | user_func_params

## Functions
double | user_pz_probability (double z_ph, double z_s, void *user_par, int *status)
int | main (int argc, char **argv)

## Function Documentation

## ◆ main()

int main | ( | int | argc,
|  | char ** | argv
| ) |  |

## ◆ user_pz_probability()

double user_pz_probability | ( | double | z_ph,
|  | double | z_s,
|  | void * | user_par,
|  | int * | status
| ) |  |